#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 indexed-traversable-instances
version:              0.1.2
visibility:           public
id:                   indexed-traversable-instances-0.1.2-4cTuAQWL0FPF9s8W5HjAFa
key:                  indexed-traversable-instances-0.1.2-4cTuAQWL0FPF9s8W5HjAFa
license:              BSD-2-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Edward Kmett
synopsis:
    More instances of FunctorWithIndex, FoldableWithIndex, TraversableWithIndex

description:
    This package provides extra instances for type-classes in the [indexed-traversable](https://hackage.haskell.org/package/indexed-traversable) package.

    The intention is to keep this package minimal;
    it provides instances that formely existed in @lens@ or @optics-extra@.
    We recommend putting other instances directly into their defining packages.
    The @indexed-traversable@ package is light, having only GHC boot libraries
    as its dependencies.

category:             Data
abi:                  10d07ea67fd535f65602dfd7999edf13
exposed:              True
exposed-modules:      Data.Functor.WithIndex.Instances
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/indexed-traversable-instances-0.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-indexed-traversable-instances
hs-libraries:
    HSindexed-traversable-instances-0.1.2-4cTuAQWL0FPF9s8W5HjAFa

depends:
    OneTuple-0.4.2-EXHhbedEwkRGvAmaHE2ooP base-4.18.2.1
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    unordered-containers-0.2.20.1-9wZ7uB8CqcR5TZZg4U4qth
    vector-0.13.2.0-Is51f3ml4GnGFciyGIODi

haddock-interfaces:
    /usr/share/doc/haskell-indexed-traversable-instances/html/indexed-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-indexed-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

